Default Settings
================

PyeLink uses validated default settings for all EyeLink tracker configuration.
All values below are auto-generated from the source code and will stay in sync
with any code changes.

.. settings-table::
